@@ -2,5 +2,7 @@ from zerohash.resources.digital_asset_addresses import DigitalAssetAddresses
 from zerohash.resources.error_object import ErrorObject
 from zerohash.resources.liquidity_execute import LiquidityExecute
 from zerohash.resources.liquidity_rfq import LiquidityRfq
+from zerohash.resources.participants import Participants
 from zerohash.resources.participants_customers_new import ParticipantCustomerNew
 from zerohash.resources.trades_batch import TradesBatch
+from zerohash.resources.transfers import Transfers
