@@ -16,7 +16,7 @@ class LiquidityRfq(APIResource):
         requestor = APIRequestor()
 
         url = cls.class_url()
-        response, _ = requestor.request("GET", url, kwargs)
+        response = requestor.request("GET", url, kwargs)
         zerohash_object = util.convert_to_zerohash_object(response)
 
         return zerohash_object
