@@ -1,4 +1,4 @@
-from zerohash import util
+from zerohash import api_requestor, util
 
 
 class ZerohashObject(dict):
@@ -18,6 +18,12 @@ class ZerohashObject(dict):
         instance.refresh_from(values, credentials)
         return instance
 
+    def request(self, method, url, params=None, headers=None):
+        requestor = api_requestor.APIRequestor()
+        response = requestor.request(method, url, params, headers)
+
+        return util.convert_to_zerohash_object(response, credentials=self.credentials)
+
     def refresh_from(self, values, credentials=None, partial=False):
         self.credentials = credentials or getattr(values, "credentials", None)
 
